Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrUC2 = errors.New("UC-2")
ErrUC2 is a semantic name for error that is thrown after attempt to encode UC-2 message as GSM 7-bit
Functions ¶
func HumaniseValidationErrors ¶
HumaniseValidationErrors makes errors less detailed
Types ¶
type CustomValidator ¶
type CustomValidator interface {
Validate(i interface{}) error
}
CustomValidator is interface for validator that matches echo.Validator
func InitValidator ¶
func InitValidator() CustomValidator
InitValidator is the CustomValidator factory method
type Datacoding ¶
type Datacoding string
Datacoding is a semantic interface for Datacoding enums
const ( // Plain is plain encoding (GSM 7-bit) Plain Datacoding = "plain" // Unicode is unicode encoding for SMS (UC-2 aka UTF-16) Unicode = "unicode" )
type Encoded ¶
type Encoded struct {
Encoding Datacoding
Messages []string
}
Encoded is a representation of message split depending on amount of symbols and encoding
Click to show internal directories.
Click to hide internal directories.